.. _Python: https://www.python.org/
.. _Django: https://www.djangoproject.com/
.. _django-smart-media: https://github.com/sveetch/django-smart-media
.. _whoosh-reloaded: https://github.com/Sygil-Dev/whoosh-reloaded
.. _django-haystack: https://github.com/django-haystack/django-haystack
.. _django-crispy-forms: https://github.com/django-crispy-forms/django-crispy-forms
.. _crispy-bootstrap5: https://github.com/django-crispy-forms/crispy-bootstrap5

=====
Atoum
=====

A Django application to manage shopping list and stock of consumables.

This is currently in beta stage development.


Dependencies
************

* `Python`_>=3.9;
* `Django`_>=4.2,<5.0;
* `django-smart-media`_>=0.3.0;
* `whoosh-reloaded`_>=2.7.5;
* `django-haystack`_>=3.3.0;
* `django-crispy-forms`_>=2.3
* `crispy-bootstrap5`_>=2024.10


Links
*****

* **Not yet** Read the documentation on `Read the docs <https://atoum.readthedocs.io/>`_;
* Download its `PyPi package <https://pypi.python.org/pypi/atoum>`_;
* Clone it on its `Github repository <https://github.com/sveetch/atoum>`_;


Credits
*******

Logo vector and icon by `SVG Repo <https://www.svgrepo.com>`_.
